"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Searcher = void 0;
const react_1 = require("react");
const DelayedSearchBox_1 = require("./DelayedSearchBox");
const react_2 = __importDefault(require("react"));
const Searcher = props => {
    var _a;
    let searchText = (0, react_1.useRef)("");
    let highlightInProgess = (0, react_1.useRef)(false);
    (0, react_1.useEffect)(() => {
        if (props.filterOnItemsChange && searchText.current)
            filterItems(searchText.current);
    }, [props.items]);
    (0, react_1.useEffect)(() => {
        filterItems(searchText.current, true);
    }, [props.customSearchFunction]);
    (0, react_1.useEffect)(() => {
        let newValueParts = searchText.current.split(" ");
        highlightSearchText(newValueParts);
    }, [props.highLightElements]);
    const filterItems = (value, initial) => {
        if (!props.items || !props.items.length)
            return;
        if (props.minCharsForSearch != null && value !== undefined && value.length != 0 && value.length < props.minCharsForSearch)
            return;
        let newValueParts = value.split(" ");
        let filteredItems = [];
        if (props.customSearchFunction)
            filteredItems = props.customSearchFunction(newValueParts);
        else {
            let propertyGetter = (item, field) => item[field];
            filteredItems = props.items.filter(item => props.searchFields.some(sf => newValueParts.every(part => new RegExp(`${part}`, "i").test(propertyGetter(item, sf)))));
        }
        if (!initial)
            props.onSearch(filteredItems, value);
        if (props.enableTextHighlight && props.highLightElements)
            highlightSearchText(newValueParts);
    };
    const highlightSearchText = (searchTextParts) => {
        if (!props.highLightElements)
            return;
        if (highlightInProgess.current)
            return;
        highlightInProgess.current = true;
        // clear highlight on new search
        var highlightElements = props.highLightElements();
        highlightElements.forEach(_ => _.innerHTML = _.innerHTML.replace(/(<span class="tp-searcher-highlight">|<\/span>)/igm, ""));
        // set highlights
        highlightElements.forEach((_) => {
            let html = _.innerHTML;
            const tagsRegEx = new RegExp('(<.+?>|&\\w+;)');
            searchTextParts.forEach((searchText, idx) => {
                var _a;
                let minChars = (_a = props.minCharsForSearch) !== null && _a !== void 0 ? _a : 0;
                if (searchText.length < minChars)
                    return;
                const htmlParts = html.split(tagsRegEx).filter(Boolean);
                html = htmlParts.map(item => tagsRegEx.test(item)
                    ? item
                    : item.replace(new RegExp(`(${searchText})`, 'ig'), `<span class="tp-searcher-highlight">$1</span>`)).join('');
            });
            _.innerHTML = html;
        });
        highlightInProgess.current = false;
    };
    return react_2.default.createElement(DelayedSearchBox_1.DelayedSearchBox, { className: `tp-panel-searchbox ${props.className ? props.className : ""}`, delay: (_a = props.delay) !== null && _a !== void 0 ? _a : 300, disabled: props.disabled, searchPlaceHolder: props.searchPlaceHolder, onChange: (text) => { searchText.current = text !== null && text !== void 0 ? text : ""; filterItems(text !== null && text !== void 0 ? text : ""); }, onFocus: props.onInputFocus });
};
exports.Searcher = Searcher;
//# sourceMappingURL=Searcher.js.map